@@ -92,6 +92,9 @@ as_gloss <- function(...,
     )
   if (output_format == "latex") {
     gloss_pdf(gloss)
+  } else if (length(gloss) == 1) {
+    # if there is only one line, i.e. no interlinear glosses
+    gloss_single(gloss, numbering = numbering)
   } else if (output_format == "word") {
     gloss_word(gloss, numbering = numbering)
   } else {
@@ -99,6 +102,7 @@ as_gloss <- function(...,
   }
 }
 
+
 #' gloss class
 #'
 #' The `gloss` class contains how a gloss will be printed and its original input
